@@ -355,15 +355,15 @@ class DynamoDBStreamToLambdaToElasticSearchAndKibanaProps:
         :summary: The properties for the DynamoDBStreamToLambdaToElastciSearchAndKibana Construct
         '''
         if isinstance(dynamo_event_source_props, dict):
-            dynamo_event_source_props = DynamoEventSourceProps(**dynamo_event_source_props)
+            dynamo_event_source_props = aws_cdk.aws_lambda_event_sources.DynamoEventSourceProps(**dynamo_event_source_props)
         if isinstance(dynamo_table_props, dict):
-            dynamo_table_props = TableProps(**dynamo_table_props)
+            dynamo_table_props = aws_cdk.aws_dynamodb.TableProps(**dynamo_table_props)
         if isinstance(es_domain_props, dict):
-            es_domain_props = CfnDomainProps(**es_domain_props)
+            es_domain_props = aws_cdk.aws_elasticsearch.CfnDomainProps(**es_domain_props)
         if isinstance(lambda_function_props, dict):
-            lambda_function_props = FunctionProps(**lambda_function_props)
+            lambda_function_props = aws_cdk.aws_lambda.FunctionProps(**lambda_function_props)
         if isinstance(sqs_dlq_queue_props, dict):
-            sqs_dlq_queue_props = QueueProps(**sqs_dlq_queue_props)
+            sqs_dlq_queue_props = aws_cdk.aws_sqs.QueueProps(**sqs_dlq_queue_props)
         if __debug__:
             type_hints = typing.get_type_hints(DynamoDBStreamToLambdaToElasticSearchAndKibanaProps.__init__)
             check_type(argname="argument domain_name", value=domain_name, expected_type=type_hints["domain_name"])
